@@ -35,14 +35,7 @@
 //  **********************************************************************
 
 # include <string.h>
-# include <Rconfig.h>
-# include <Rdefines.h>
-# include <Rembedded.h>
-# include <R.h>
-# include <Rinternals.h>
-# include <Rmath.h>
-# include <Rversion.h>
-
+# include <S.h>
 # include <time.h>
 # include <math.h>
 # include <stdio.h>
@@ -55,6 +48,16 @@
 // model fitting functions
 # include "RLT.h"
 
+// R functions
+# include <Rconfig.h>
+# include <Rdefines.h>
+# include <Rembedded.h>
+# include <R.h>
+# include <Rinternals.h>
+# include <Rmath.h>
+# include <Rversion.h>
+
+
 // #define CSTACK_DEFNS 7
 
 SEXP RLT_regression(SEXP datasetX_R,
